import { CfnInclude, IncludedNestedStack } from 'aws-cdk-lib/cloudformation-include';
import * as cdk from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { AmplifyExportedBackendProps } from './amplify-exported-backend-props';
import { BaseAmplifyExportedBackend } from './base-exported-backend';
import { APIGraphQLIncludedNestedStack, APIRestIncludedStack, AuthIncludedNestedStack } from './include-nested-stacks';
import { LambdaFunctionIncludedNestedStack } from './include-nested-stacks/lambda-function/lambda-function-nested-stack';
/***
 * Used to include the backend generated by running `amplify export --out <path>` into the cdk app
 * @example
 * @see <amplify-export-docs-path>
 */
export declare class AmplifyExportedBackend extends BaseAmplifyExportedBackend {
    /**
     * cfnInclude of the Amplify backend
     */
    cfnInclude: CfnInclude;
    /**
     * The root stack created
     */
    rootStack: cdk.Stack;
    /**
     * @param scope The parent construct of this template
     * @param id The ID of this construct
     * @param props Initialization properties.
     */
    constructor(scope: Construct, id: string, props: AmplifyExportedBackendProps);
    private applyTags;
    /**
     * Method to get the auth stack
     * @returns the nested stack of type {IAuthIncludeNestedStack}
     * @throws {AmplifyCategoryNotFoundError} if the auth stack doesn't exist
     * @method
     * @function
     */
    authNestedStack(): AuthIncludedNestedStack;
    /**
     * Use this to get the api graphql stack from the backend
     * @returns the nested stack of type {IAPIGraphQLIncludeNestedStack}
     * @
     * @throws {AmplifyCategoryNotFoundError} if the API graphql stack doesn't exist
     */
    graphqlNestedStacks(): APIGraphQLIncludedNestedStack;
    /**
     * Use this to get all the lambda functions from the backend
     * @returns {ILambdaFunctionIncludedNestedStack[]}
     * @throws {AmplifyCategoryNotFoundError} if the no Lambda Function stacks are found
     */
    lambdaFunctionNestedStacks(): LambdaFunctionIncludedNestedStack[];
    /**
     * Use this to get a specific lambda function from the backend
     * @returns {ILambdaFunctionIncludedNestedStack}
     * @param functionName the function name to get from the nested stack
     * @throws {AmplifyCategoryNotFoundError} if the lambda function stack doesn't exist
     */
    lambdaFunctionNestedStackByName(functionName: string): LambdaFunctionIncludedNestedStack;
    nestedStackByCategortService(category: string, service: string): IncludedNestedStack[];
    /**
     * Returns the stacks defined in the backend
     * @param category Categories defined in Amplify CLI like function, api, auth etc
     * @param resourceName @default is undefined
     */
    nestedStacksByCategory(category: string, resourceName?: string): IncludedNestedStack[];
    /**
     * Use this to get rest api stack from the backend
     * @param resourceName
     * @return {IAPIRestIncludedStack} the nested of type Rest API
     * @throws {AmplifyCategoryNotFoundError} if the API Rest stack doesn't exist
     */
    apiRestNestedStack(resourceName: string): APIRestIncludedStack;
    private getCategoryNestedStack;
}
